==> react-molecule-autosuggest-2.8.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React, { useRef, useState } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { moleculeDropdownListSizes as SIZES } from '@s-ui/react-molecule-dropdown-list';
import MoleculeAutosuggestSingleSelection from './components/SingleSelection';
import MoleculeAutosuggestMultipleSelection from './components/MultipleSelection';
import { withOpenToggle } from '@s-ui/hoc';
import { getTarget } from '@s-ui/js/lib/react';
import { getCurrentElementFocused } from '@s-ui/js/lib/dom';
var BASE_CLASS = "sui-MoleculeAutosuggest";
var CLASS_FOCUS = BASE_CLASS + "--focus";
var CLASS_DISABLED = BASE_CLASS + "--disabled";
var AUTOSUGGEST_STATES = {
  ERROR: 'error',
  SUCCESS: 'success',
  ALERT: 'alert'
};

var getIsTypeableKey = function getIsTypeableKey(key) {
  var keysEdit = ['Backspace', 'Enter', 'Meta', 'Shift', 'ArrowLeft', 'ArrowRight'];
  return key.length === 1 || keysEdit.includes(key);
};

var MoleculeAutosuggest = function MoleculeAutosuggest(_ref) {
  var _cx;

  var multiselection = _ref.multiselection,
      props = _objectWithoutPropertiesLoose(_ref, ["multiselection"]);

  var refMoleculeAutosuggestFromProps = props.refMoleculeAutosuggest,
      children = props.children,
      onToggle = props.onToggle,
      onChange = props.onChange,
      onEnter = props.onEnter,
      isOpen = props.isOpen,
      keysCloseList = props.keysCloseList,
      keysSelection = props.keysSelection,
      disabled = props.disabled,
      errorState = props.errorState,
      state = props.state;
  var refMoleculeAutosuggest = useRef(refMoleculeAutosuggestFromProps === null || refMoleculeAutosuggestFromProps === void 0 ? void 0 : refMoleculeAutosuggestFromProps.current);
  var refsMoleculeAutosuggestOptions = useRef([]);
  var refMoleculeAutosuggestInput = useRef();

  var _useState = useState(false),
      focus = _useState[0],
      setFocus = _useState[1];

  var extendedChildren = React.Children.toArray(children).filter(Boolean).map(function (child, index) {
    refsMoleculeAutosuggestOptions.current[index] = React.createRef();
    return React.cloneElement(child, {
      innerRef: refsMoleculeAutosuggestOptions.current[index],
      onSelectKey: keysSelection
    });
  });
  var className = cx(BASE_CLASS, errorState && BASE_CLASS + "--" + AUTOSUGGEST_STATES.ERROR, errorState === false && BASE_CLASS + "--" + AUTOSUGGEST_STATES.SUCCESS, state && BASE_CLASS + "--" + state, (_cx = {}, _cx[CLASS_FOCUS] = focus, _cx[CLASS_DISABLED] = disabled, _cx));

  var closeList = function closeList(ev) {
    var domMoleculeAutosuggest = refMoleculeAutosuggest.current;
    onToggle(ev, {
      isOpen: false
    });
    if (multiselection) onChange(ev, {
      value: ''
    });
    domMoleculeAutosuggest && domMoleculeAutosuggest.focus();
    setFocus(false);
    ev.preventDefault();
    ev.stopPropagation();
  };

  var focusFirstOption = function focusFirstOption(ev, _ref2) {
    var options = _ref2.options;
    if (options[0]) options[0].focus();
    ev.preventDefault();
    ev.stopPropagation();
  };

  var handleKeyDown = function handleKeyDown(ev) {
    ev.persist();
    var domInnerInput = refMoleculeAutosuggestInput.current;
    var domMoleculeAutosuggest = refMoleculeAutosuggest.current;
    var optionsFromRef = refsMoleculeAutosuggestOptions.current;
    var key = ev.key;
    var options = optionsFromRef.map(getTarget);
    var isTypeableKey = getIsTypeableKey(key);
    var isSelectionKey = keysSelection.includes(key);

    if (isTypeableKey) {
      if (!isSelectionKey) domInnerInput.focus();
    } else domMoleculeAutosuggest.focus();

    if (isOpen) {
      var currentElementFocused = getCurrentElementFocused();
      var isSomeOptionFocused = [].concat(options).includes(currentElementFocused);
      if (keysCloseList.includes(key)) closeList(ev);else if (key === 'ArrowDown' && !isSomeOptionFocused) focusFirstOption(ev, {
        options: options
      });else if (isSomeOptionFocused) handleFocusIn(ev);
    } else {
      if (key === 'Enter') {
        onEnter();
      }
    }
  };

  var handleFocusIn = function handleFocusIn(ev) {
    return setFocus(true);
  };

  var handleFocusOut = function handleFocusOut(ev) {
    ev.persist();
    var domInnerInput = refMoleculeAutosuggestInput.current;
    var optionsFromRef = refsMoleculeAutosuggestOptions.current;
    var options = optionsFromRef.map(getTarget);
    setTimeout(function () {
      var currentElementFocused = getCurrentElementFocused();
      var focusOutFromOutside = ![domInnerInput].concat(options).includes(currentElementFocused);

      if (focusOutFromOutside) {
        isOpen ? closeList(ev) : setFocus(false);
      }
    }, 1);
    setFocus(true);
  };

  var handleInputKeyDown = function handleInputKeyDown(ev) {
    var key = ev.key;
    if (key !== 'ArrowDown') ev.stopPropagation();

    if (key === 'Enter') {
      onEnter();
    }
  };

  return React.createElement("div", {
    ref: refMoleculeAutosuggest,
    tabIndex: "0",
    className: className,
    onKeyDown: handleKeyDown,
    onFocus: handleFocusIn,
    onBlur: handleFocusOut
  }, multiselection ? React.createElement(MoleculeAutosuggestMultipleSelection, Object.assign({}, props, {
    onInputKeyDown: handleInputKeyDown,
    refMoleculeAutosuggest: refMoleculeAutosuggest,
    innerRefInput: refMoleculeAutosuggestInput
  }), extendedChildren) : React.createElement(MoleculeAutosuggestSingleSelection, Object.assign({}, props, {
    onInputKeyDown: handleInputKeyDown,
    refMoleculeAutosuggest: refMoleculeAutosuggest,
    innerRefInput: refMoleculeAutosuggestInput
  }), extendedChildren));
};

MoleculeAutosuggest.defaultProps = {
  onChange: function onChange() {},
  onBlur: function onBlur() {},
  onToggle: function onToggle() {},
  onEnter: function onEnter() {},
  onSelect: function onSelect() {},
  keysSelection: [' ', 'Enter'],
  keysCloseList: ['Escape']
};
export default withOpenToggle(MoleculeAutosuggest);
export { SIZES as MoleculeAutosuggestDropdownListSizes };
export { AUTOSUGGEST_STATES as MoleculeAutosuggestStates };

==> react-molecule-autosuggest-2.9.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React, { useRef, useState } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { moleculeDropdownListSizes as SIZES } from '@s-ui/react-molecule-dropdown-list';
import MoleculeAutosuggestSingleSelection from './components/SingleSelection';
import MoleculeAutosuggestMultipleSelection from './components/MultipleSelection';
import { withOpenToggle } from '@s-ui/hoc';
import { getTarget } from '@s-ui/js/lib/react';
import { getCurrentElementFocused } from '@s-ui/js/lib/dom';
var BASE_CLASS = "sui-MoleculeAutosuggest";
var CLASS_FOCUS = BASE_CLASS + "--focus";
var CLASS_DISABLED = BASE_CLASS + "--disabled";
var AUTOSUGGEST_STATES = {
  ERROR: 'error',
  SUCCESS: 'success',
  ALERT: 'alert'
};

var getIsTypeableKey = function getIsTypeableKey(key) {
  var keysEdit = ['Backspace', 'Enter', 'Meta', 'Shift', 'ArrowLeft', 'ArrowRight'];
  return key.length === 1 || keysEdit.includes(key);
};

var MoleculeAutosuggest = function MoleculeAutosuggest(_ref) {
  var _cx;

  var multiselection = _ref.multiselection,
      props = _objectWithoutPropertiesLoose(_ref, ["multiselection"]);

  var refMoleculeAutosuggestFromProps = props.refMoleculeAutosuggest,
      children = props.children,
      onToggle = props.onToggle,
      onChange = props.onChange,
      onEnter = props.onEnter,
      isOpen = props.isOpen,
      keysCloseList = props.keysCloseList,
      keysSelection = props.keysSelection,
      disabled = props.disabled,
      errorState = props.errorState,
      state = props.state;
  var refMoleculeAutosuggest = useRef(refMoleculeAutosuggestFromProps == null ? void 0 : refMoleculeAutosuggestFromProps.current);
  var refsMoleculeAutosuggestOptions = useRef([]);
  var refMoleculeAutosuggestInput = useRef();

  var _useState = useState(false),
      focus = _useState[0],
      setFocus = _useState[1];

  var extendedChildren = React.Children.toArray(children).filter(Boolean).map(function (child, index) {
    refsMoleculeAutosuggestOptions.current[index] = React.createRef();
    return React.cloneElement(child, {
      innerRef: refsMoleculeAutosuggestOptions.current[index],
      onSelectKey: keysSelection
    });
  });
  var className = cx(BASE_CLASS, errorState && BASE_CLASS + "--" + AUTOSUGGEST_STATES.ERROR, errorState === false && BASE_CLASS + "--" + AUTOSUGGEST_STATES.SUCCESS, state && BASE_CLASS + "--" + state, (_cx = {}, _cx[CLASS_FOCUS] = focus, _cx[CLASS_DISABLED] = disabled, _cx));

  var closeList = function closeList(ev) {
    var domMoleculeAutosuggest = refMoleculeAutosuggest.current;
    onToggle(ev, {
      isOpen: false
    });
    if (multiselection) onChange(ev, {
      value: ''
    });
    domMoleculeAutosuggest && !focus && domMoleculeAutosuggest.focus();
    setFocus(false);
    ev.preventDefault();
    ev.stopPropagation();
  };

  var focusFirstOption = function focusFirstOption(ev, _ref2) {
    var options = _ref2.options;
    if (options[0]) options[0].focus();
    ev.preventDefault();
    ev.stopPropagation();
  };

  var handleKeyDown = function handleKeyDown(ev) {
    ev.persist();
    var domInnerInput = refMoleculeAutosuggestInput.current;
    var domMoleculeAutosuggest = refMoleculeAutosuggest.current;
    var optionsFromRef = refsMoleculeAutosuggestOptions.current;
    var key = ev.key;
    var options = optionsFromRef.map(getTarget);
    var isTypeableKey = getIsTypeableKey(key);
    var isSelectionKey = keysSelection.includes(key);

    if (isTypeableKey) {
      if (!isSelectionKey) domInnerInput.focus();
    } else domMoleculeAutosuggest.focus();

    if (isOpen) {
      var currentElementFocused = getCurrentElementFocused();
      var isSomeOptionFocused = [].concat(options).includes(currentElementFocused);
      if (keysCloseList.includes(key)) closeList(ev);else if (key === 'ArrowDown' && !isSomeOptionFocused) focusFirstOption(ev, {
        options: options
      });else if (isSomeOptionFocused) handleFocusIn(ev);
    } else {
      if (key === 'Enter') {
        onEnter();
      }
    }
  };

  var handleFocusIn = function handleFocusIn(ev) {
    return setFocus(true);
  };

  var handleFocusOut = function handleFocusOut(ev) {
    ev.persist();
    var domInnerInput = refMoleculeAutosuggestInput.current;
    var optionsFromRef = refsMoleculeAutosuggestOptions.current;
    var options = optionsFromRef.map(getTarget);
    setTimeout(function () {
      var currentElementFocused = getCurrentElementFocused();
      var focusOutFromOutside = ![domInnerInput].concat(options).includes(currentElementFocused);

      if (focusOutFromOutside) {
        isOpen ? closeList(ev) : setFocus(false);
      }
    }, 1);
    setFocus(true);
  };

  var handleInputKeyDown = function handleInputKeyDown(ev) {
    var key = ev.key;
    if (key !== 'ArrowDown') ev.stopPropagation();

    if (key === 'Enter') {
      onEnter();
    }
  };

  return React.createElement("div", {
    ref: refMoleculeAutosuggest,
    tabIndex: "0",
    className: className,
    onKeyDown: handleKeyDown,
    onFocus: handleFocusIn,
    onBlur: handleFocusOut
  }, multiselection ? React.createElement(MoleculeAutosuggestMultipleSelection, Object.assign({}, props, {
    onInputKeyDown: handleInputKeyDown,
    refMoleculeAutosuggest: refMoleculeAutosuggest,
    innerRefInput: refMoleculeAutosuggestInput
  }), extendedChildren) : React.createElement(MoleculeAutosuggestSingleSelection, Object.assign({}, props, {
    onInputKeyDown: handleInputKeyDown,
    refMoleculeAutosuggest: refMoleculeAutosuggest,
    innerRefInput: refMoleculeAutosuggestInput
  }), extendedChildren));
};

MoleculeAutosuggest.defaultProps = {
  onChange: function onChange() {},
  onBlur: function onBlur() {},
  onToggle: function onToggle() {},
  onEnter: function onEnter() {},
  onSelect: function onSelect() {},
  keysSelection: [' ', 'Enter'],
  keysCloseList: ['Escape']
};
export default withOpenToggle(MoleculeAutosuggest);
export { SIZES as MoleculeAutosuggestDropdownListSizes };
export { AUTOSUGGEST_STATES as MoleculeAutosuggestStates };
